
# Load libraries
library(MASS)
library(ordinal) # Also for ordered probit
library(pscl)
library(ZeligChoice)
library(AER)


data <- read.table("D:/R_Package_Estimation/testmodels.csv", header=T, sep=",");
##### Descriptive Statistics #####
# stat.desc(data,basic=TRUE, desc=TRUE, norm=FALSE, p=0.95); 


# 1. Linear Regression Model
#
# Three arguments are needed
# 1) Dependent variable - Y
# 2) Independent Variable (Regressor) - X 
# 3) Input table as Data.Frame

tmp1 <- lm(Trans_motor ~ DRVRCNT+RUR+INCOME1+INCOME5, data=data);
summary(tmp1);



# 2. Poisson Regression Model
#
# Three arguments are needed
# 1) Dependent variable - Y
# 2) Independent Variable (Regressor) - X
# 3) Input table as Data.Frame

tmp2 <- glm(NUMCHILD ~ INCOME2+INCOME5, family=poisson, data=data);
summary(tmp2);


# Overdispersion Test
Y <- data$NUMCHILD
pre_poi <- predict(tmp2, type="response");
z <- ((Y - pre_poi)^2 - Y) / sqrt(2*pre_poi);
wi1 <- pre_poi / (sqrt(2*pre_poi));
wi2 <- pre_poi^2 / (sqrt(2*pre_poi));

wi1_hat <- lm(z ~ 0 + wi1, data);
summary(wi1_hat);

wi2_hat <- lm(z ~ 0 + wi2, data);
summary(wi2_hat);


# 3. Negative-binomial Regression Model
#
# Three arguments are needed
# 1) Dependent variable - Y
# 2) Independent Variable (Regressor) - X
# 3) Input table as Data.Frame

tmp3 <- glm.nb(NUMCHILD ~ INCOME2+INCOME5, data=data);
summary(tmp3);


# 4. Zero-Inflated Poisson Regression Model
#
# Four arguments are needed
# 1) Dependent variable - Y
# 2) Independent variable(s) for count model
# 3) Independent variable(s) for zero-inflation model
# 4) Input table as Data.Frame

tmp4 <- zeroinfl(NUMCHILD ~ INCOME2+INCOME5 | 1, data = data);
summary(tmp4);

# Vuong Test
vuong(tmp2, tmp4);


# 5. Zero-Inflated Negative-binomial Regression Model
#
# Four arguments are needed
# 1) Dependent variable - Y
# 2) Independent variable(s) for count model
# 3) Independent variable(s) for zero-inflation model
# 4) Input table as Data.Frame

tmp5 <- zeroinfl(NUMCHILD ~ INCOME2+INCOME5 | 1, data = data, dist= "negbin", EM = TRUE);
summary(tmp5);



#
# Example for adding columns (new variables) to input data
#
data$ncar1 <- data$NCAR
data$ncar1 [data$NCAR >= 4] <- 3
data$ncar2 <- data$ncar1 - 1
data$obs_ncar <- data$ncar1
data$ncar2 <- factor(data$ncar2)

# 6. Ordered Probit Model
#
# Three arguments are needed
# 1) Dependent variable - Y
# 2) Independent Variable (Regressor) - X
# 3) Input table as Data.Frame

tmp6 <- clm(ncar2 ~ 1+YCAR0_5+INCOME2+INCOME5+WORK3+NUMADLT+HSIZE1+OWN, data = data, link = 'probit', threshold = 'flexible');
summary(tmp6);




##### Example for adding columns (new variables) #####
data$const <- 1

data$lif_cyc_1 <- 0
data$lif_cyc_1[data$LIF_CYC == 4] <- 1
data$lif_cyc_2 <- 0
data$lif_cyc_2[data$LIF_CYC == 8] <- 1

data$inc1_1 <- data$INCOME1 * data$const 
data$inc2_1 <- data$INCOME2 * data$const
data$own_1 <- data$OWN * data$const
data$hsiz1_1 <- data$HSIZE1 * data$const

data$inc1_2 <- data$INCOME1 * data$const
data$inc2_2 <- data$INCOME2 * data$const
data$hsiz1_2 <- data$HSIZE1 * data$const

data$lif_cyc4_3 <- data$lif_cyc_1 * data$const
data$inc3_3 <- data$INCOME3 * data$const
data$wrkr2_3 <- data$WORK2 * data$const

data$own_4 <- data$OWN * data$const
data$nadlt_4 <- data$NUMADLT * data$const
data$wrkr3_4 <- data$WORK3 * data$const

data$inc5_5 <- data$INCOME5 * data$const
data$lif_cyc8_5 <- data$lif_cyc_2 * data$const
data$hsiz4_5 <- data$HSIZE4 * data$const



# 7. Multinomial Logit Model
#
# Assumption: All cases should have the same set of choice to do discrete choice.  
# For example, in this assumption, all households only have a choice set of car, van, suv, or pick-up truck. 
# That is, all households choose a vehicle for buying in four body types.
# Note that the MNL function in this package does not allow that different cases have different choice set.  
#
# Three arguments are needed
# 1. Dependent variable - Y
# 2. A vector that should include choice values in the column of the dependent variable. 
#    In this example, dependent variable is "Index1" with five different values 1 through 5
#    Note that there are total 6 choices in this example.  However, the last choice should be fixed so that it is hide.
# 3. Independent Variable (Regressor) as a list - all choices have their own regressor except the last choice because it is fixed.
# 4. Input table as Data.Frame
# 
# Note, if a variable should be used in different choices, this variable should be copied with different name.  
# In this example, Variable "INCOME1" is used in choice 1 and 2. Therefore, two variables "inc1_1" and "inc1_2" were created 
# and contain exactly the same as "INCOME1" (see line 104 through line 134).

# MNL Example for different utility functions by alternatives
utilities <- list(id(Index1, 1) ~ inc1_1+inc2_1+own_1+hsiz1_1, 
                  id(Index1, 2) ~ inc1_2+inc2_2+hsiz1_2, 
                  id(Index1, 3) ~ lif_cyc4_3+inc3_3+wrkr2_3,  
                  id(Index1, 4) ~ own_4+nadlt_4+wrkr3_4,
                  id(Index1, 5) ~ inc5_5+lif_cyc8_5+hsiz4_5);

tmp7 <- zelig(utilities, model = "mlogit", data = data);
summary(tmp7);


# MNL Example for one utility function across all alternatives
tmp8 <- zelig(as.factor(Index1) ~ INCOME1 + HSIZE1,  model = "mlogit", data = data);
summary(tmp8);


